Crate leptrino_force_torque_sensor

Crate leptrino_force_torque_sensor 

Unofficial device driver for Leptrino force torque sensors.

Line up of Leptrino sensor is available here.

Examples

use leptrino_force_torque_sensor::{LeptrinoSensor, Product};

let mut sensor = LeptrinoSensor::open(Product::Pfs055Ya251U6, "/dev/ttyUSB0").unwrap();

let wrench = sensor.update().unwrap();
println!("{:?}", wrench);

Dependency under Linux environment

libudev-dev is required under Linux environment. Please install it by
sudo apt install libudev-dev

Setup

It may be required to customize udev rules if you use usb-connected sensors.

This shell script can be useful for customize (see the file in detail).

Note

I tested this crate only by Pfs055Ya251U6 sensor because I have no other Leptrino sensor.

Re-exports

pub use serialport;

Structs

LeptrinoSensor
Leptrino 6-axis force-torque sensor.
ProductInfo
Represents product information of a connected sensor.
Triplet
Represents a pair consisting of 3 values.
Wrench
A pair of force and torque.

Enums

Error
Represents an error occurred while communicating sensors.
ParseError
Represents an error that occurred during parsing a received message from a sensor.
Product
Specify a product type of Leptrino force torque sensor.